Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DetectType ¶ added in v0.6.0
DetectType returns the database type string for a given DSN.
func DisplayName ¶ added in v0.6.0
DisplayName returns a short display name for a DSN.
func InitialQuery ¶ added in v0.6.0
InitialQuery returns an appropriate initial query for the database type.
func MaskDSN ¶ added in v0.6.0
MaskDSN returns a display-safe version of the DSN with passwords masked.
func Placeholder ¶ added in v0.6.0
Placeholder returns an appropriate placeholder query for the database type.
Types ¶
Click to show internal directories.
Click to hide internal directories.